@@ -243,7 +243,7 @@ impl BridgedType {
                 if let Some(ty) = types.get_with_type_path(path) {
                     Some(ty.to_bridged_type(false, false))
                 } else {
-                    Self::with_str(
+                    Self::new_with_str(
                         path.path.segments.to_token_stream().to_string().as_str(),
                         types,
                     )
@@ -305,7 +305,7 @@ impl BridgedType {
         }
     }
 
-    pub fn with_str(string: &str, types: &TypeDeclarations) -> Option<BridgedType> {
+    pub fn new_with_str(string: &str, types: &TypeDeclarations) -> Option<BridgedType> {
         if string.starts_with("Vec < ") {
             let inner = string.trim_start_matches("Vec < ");
             let inner = inner.trim_end_matches(" >");
@@ -434,11 +434,7 @@ impl BridgedType {
     // U8 -> u8
     // RefSlice(U8) -> FfiSlice
     // Str -> RustStr
-    pub fn to_ffi_compatible_rust_type(
-        &self,
-        func_host_lang: HostLang,
-        swift_bridge_path: &Path,
-    ) -> TokenStream {
+    pub fn to_ffi_compatible_rust_type(&self, swift_bridge_path: &Path) -> TokenStream {
         let ty = match self {
             BridgedType::StdLib(stdlib_type) => match stdlib_type {
                 StdLibType::U8 => quote! {u8},
@@ -458,9 +454,7 @@ impl BridgedType {
                     let kind = ptr.kind.to_token_stream();
 
                     let ty = match &ptr.pointee {
-                        Pointee::BuiltIn(ty) => {
-                            ty.to_ffi_compatible_rust_type(func_host_lang, swift_bridge_path)
-                        }
+                        Pointee::BuiltIn(ty) => ty.to_ffi_compatible_rust_type(swift_bridge_path),
                         Pointee::Void(ty) => {
                             quote! { super::#ty }
                         }
@@ -469,9 +463,7 @@ impl BridgedType {
                     quote! { #kind #ty}
                 }
                 StdLibType::RefSlice(slice) => {
-                    let ty = slice
-                        .ty
-                        .to_ffi_compatible_rust_type(func_host_lang, swift_bridge_path);
+                    let ty = slice.ty.to_ffi_compatible_rust_type(swift_bridge_path);
                     quote! {#swift_bridge_path::FfiSlice<#ty>}
                 }
                 StdLibType::Str => {
@@ -540,9 +532,7 @@ impl BridgedType {
                         StdLibType::Str => {
                             quote! { #swift_bridge_path::string::RustStr }
                         }
-                        StdLibType::String => opt
-                            .ty
-                            .to_ffi_compatible_rust_type(func_host_lang, swift_bridge_path),
+                        StdLibType::String => opt.ty.to_ffi_compatible_rust_type(swift_bridge_path),
                         StdLibType::Vec(_) => {
                             todo!("Option<Vec<T>> is not yet supported")
                         }
@@ -593,12 +583,7 @@ impl BridgedType {
                         quote! { *mut super::#ty_name }
                     }
                 } else {
-                    if func_host_lang.is_rust() {
-                        // quote_spanned! {ty_name.span()=> *mut std::ffi::c_void }
-                        quote! { #ty_name }
-                    } else {
-                        quote! { #ty_name }
-                    }
+                    quote! { #ty_name }
                 }
             }
         };
@@ -661,54 +646,38 @@ impl BridgedType {
                     }
                 }
                 StdLibType::Null => "()".to_string(),
-                StdLibType::Str => {
-                    match type_pos {
-                        TypePosition::FnArg(func_host_lang) => {
-                            if func_host_lang.is_rust() {
-                                "GenericToRustStr".to_string()
-                            } else {
-                                "RustStr".to_string()
-                            }
-                        }
-                        TypePosition::FnReturn(func_host_lang) => {
-                            if func_host_lang.is_rust() {
-                                "RustStr".to_string()
-                            } else {
-                                "RustStr".to_string()
-                            }
-                        }
-                        TypePosition::SharedStructField => {
-                            //
-                            unimplemented!()
+                StdLibType::Str => match type_pos {
+                    TypePosition::FnArg(func_host_lang) => {
+                        if func_host_lang.is_rust() {
+                            "GenericToRustStr".to_string()
+                        } else {
+                            "RustStr".to_string()
                         }
                     }
-                }
+                    TypePosition::FnReturn(_func_host_lang) => "RustStr".to_string(),
+                    TypePosition::SharedStructField => "RustStr".to_string(),
+                },
                 StdLibType::String => match type_pos {
                     TypePosition::FnArg(_func_host_lang) => "GenericIntoRustString".to_string(),
                     TypePosition::FnReturn(_func_host_lang) => "RustString".to_string(),
-                    TypePosition::SharedStructField => {
-                        todo!("String fields in shared structs are not yet supported.")
-                    }
+                    TypePosition::SharedStructField => "RustString".to_string(),
                 },
                 StdLibType::Vec(ty) => {
                     format!("RustVec<{}>", ty.ty.to_swift_type(type_pos))
                 }
-                StdLibType::Option(opt) => {
-                    match type_pos {
-                        TypePosition::FnArg(func_host_lang)
-                        | TypePosition::FnReturn(func_host_lang) => {
-                            if func_host_lang.is_swift() {
-                                opt.ty.to_swift_type(type_pos)
-                            } else {
-                                format!("Optional<{}>", opt.ty.to_swift_type(type_pos))
-                            }
-                        }
-                        TypePosition::SharedStructField => {
-                            //
-                            unimplemented!()
+                StdLibType::Option(opt) => match type_pos {
+                    TypePosition::FnArg(func_host_lang)
+                    | TypePosition::FnReturn(func_host_lang) => {
+                        if func_host_lang.is_swift() {
+                            opt.ty.to_swift_type(type_pos)
+                        } else {
+                            format!("Optional<{}>", opt.ty.to_swift_type(type_pos))
                         }
                     }
-                }
+                    TypePosition::SharedStructField => {
+                        format!("Optional<{}>", opt.ty.to_swift_type(type_pos))
+                    }
+                },
             },
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(shared_struct))) => {
                 match type_pos {
@@ -869,8 +838,8 @@ impl BridgedType {
     // If value bar is a &str.. `bar` becomes `swiftbridge::string::RustStr::from_str(bar)`
     pub fn convert_rust_value_to_ffi_compatible_value(
         &self,
-        swift_bridge_path: &Path,
         expression: &TokenStream,
+        swift_bridge_path: &Path,
     ) -> TokenStream {
         match self {
             BridgedType::StdLib(stdlib_type) => match stdlib_type {
@@ -956,12 +925,7 @@ impl BridgedType {
     // RustStr -> &str
     // *mut RustString -> String
     // FfiSlice<u8> -> &[u8]
-    pub fn convert_ffi_value_to_rust_value(
-        &self,
-        value: &TokenStream,
-        type_pos: TypePosition,
-        span: Span,
-    ) -> TokenStream {
+    pub fn convert_ffi_value_to_rust_value(&self, value: &TokenStream, span: Span) -> TokenStream {
         match self {
             BridgedType::StdLib(stdlib_type) => match stdlib_type {
                 StdLibType::Null
@@ -1000,7 +964,7 @@ impl BridgedType {
                     }
                 }
                 StdLibType::Option(bridged_option) => {
-                    bridged_option.convert_ffi_value_to_rust_value(value, type_pos)
+                    bridged_option.convert_ffi_value_to_rust_value(value)
                 }
             },
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
@@ -1052,7 +1016,7 @@ impl BridgedType {
     //
     // Where this function converts
     //  `__swift_bridge__$create_string(str)` to `RustString(ptr: __swift_bridge__$create_string(str))`
-    pub fn convert_ffi_value_to_swift_value(&self, type_pos: TypePosition, value: &str) -> String {
+    pub fn convert_ffi_value_to_swift_value(&self, value: &str, type_pos: TypePosition) -> String {
         match self {
             BridgedType::StdLib(stdlib_type) => match stdlib_type {
                 StdLibType::Null
