@@ -92,7 +92,7 @@ mod into_return_type_attribute_for_shared_struct {
 
     fn expected_rust_tokens() -> ExpectedRustTokens {
         ExpectedRustTokens::Contains(quote! {
-            fn __swift_bridge__some_function() -> __swift_bridge__StructName1 {
+            pub extern "C" fn __swift_bridge__some_function() -> __swift_bridge__StructName1 {
                  { let val: StructName1 = super::some_function().into(); val }.into_ffi_repr()
             }
         })
@@ -118,6 +118,42 @@ mod into_return_type_attribute_for_shared_struct {
     }
 }
 
+/// Verify that we can use `return_with` to convert a return type.
+mod return_with {
+    use super::*;
+
+    fn bridge_module_tokens() -> TokenStream {
+        quote! {
+            #[swift_bridge::bridge]
+            mod ffi {
+                extern "Rust" {
+                    #[swift_bridge(return_with = path::to::convert_fn)]
+                    fn some_function() -> u32;
+                }
+            }
+        }
+    }
+
+    fn expected_rust_tokens() -> ExpectedRustTokens {
+        ExpectedRustTokens::Contains(quote! {
+            pub extern "C" fn __swift_bridge__some_function() -> u32 {
+                super::path::to::convert_fn(super::some_function())
+            }
+        })
+    }
+
+    #[test]
+    fn return_with() {
+        CodegenTest {
+            bridge_module: bridge_module_tokens().into(),
+            expected_rust_tokens: expected_rust_tokens(),
+            expected_swift_code: ExpectedSwiftCode::SkipTest,
+            expected_c_header: ExpectedCHeader::SkipTest,
+        }
+        .test();
+    }
+}
+
 /// Verify that we can annotate that a function should serve as the Identifiable protocol extension.
 mod protocol_identifiable {
     use super::*;
