@@ -51,8 +51,7 @@ impl ParsedExternFn {
                         }
                     } else if let Some(built_in) = BridgedType::new_with_type(&pat_ty.ty, types) {
                         let pat = &pat_ty.pat;
-                        let ty =
-                            built_in.to_ffi_compatible_rust_type(self.host_lang, swift_bridge_path);
+                        let ty = built_in.to_ffi_compatible_rust_type(swift_bridge_path);
                         params.push(quote! { #pat: #ty});
                         continue;
                     } else {
